@@ -9,7 +9,7 @@ declare(strict_types=1);
 
 namespace OCA\Mail\IMAP;
 
-class MessageStructureData {
+final class MessageStructureData {
 	/** @var bool */
 	private $hasAttachments;
 
@@ -20,15 +20,18 @@ class MessageStructureData {
 	private $isImipMessage;
 
 	private bool $isEncrypted;
+	private bool $mentionsMe;
 
 	public function __construct(bool $hasAttachments,
 		string $previewText,
 		bool $isImipMessage,
-		bool $isEncrypted) {
+		bool $isEncrypted,
+		bool $mentionsMe) {
 		$this->hasAttachments = $hasAttachments;
 		$this->previewText = $previewText;
 		$this->isImipMessage = $isImipMessage;
 		$this->isEncrypted = $isEncrypted;
+		$this->mentionsMe = $mentionsMe;
 	}
 
 	public function hasAttachments(): bool {
@@ -46,4 +49,8 @@ class MessageStructureData {
 	public function isEncrypted(): bool {
 		return $this->isEncrypted;
 	}
+
+	public function getMentionsMe(): bool {
+		return $this->mentionsMe;
+	}
 }
